# grunt-assemble-sitemap [![NPM version](https://badge.fury.io/js/grunt-assemble-sitemap.svg)](http://badge.fury.io/js/grunt-assemble-sitemap)  [![Build Status](https://travis-ci.org/assemble/grunt-assemble-sitemap.svg)](https://travis-ci.org/assemble/grunt-assemble-sitemap)

> Sitemap plugin for Assemble

## Table of Contents

<!-- toc -->

* [Options](#options)
* [Usage Examples](#usage-examples)
* [Contributing](#contributing)
* [Other grunt-assemble plugins](#other-grunt-assemble-plugins)
* [Author](#author)
* [License](#license)
* [Changes](#changes)

_(Table of contents generated by [verb])_

<!-- tocstop -->

```sh
$ npm i grunt-assemble-sitemap --save
```

Next, register the plugin with Assemble:

```js
assemble: {
  options: {
    plugins: ['grunt-assemble-sitemap', 'other/plugins/*']
  }
}
```

Visit the [plugins docs](http://assemble.io/plugins/) for more info or for help getting started.

## Options

See [sitemaps.org](http://www.sitemaps.org/protocol.html#xmlTagDefinitions) for detail XML tag definitions.

## dest

Type: `String`

Default: `undefined`

Sitemap destination. If not set, fallback to assemble destination.

## homepage

Type: `String`

Default: `homepage` (from package.json)

Site URL

## changefreq

Type: `String`

Default: `weekly`

How frequently the page is likely to change. This value provides general information to search engines and may not correlate exactly to how often they crawl the page. Valid values are:

* always
* hourly
* daily
* weekly
* monthly
* yearly
* never

## priority

Type: `Float`

Default: `0.5`

The priority of this URL relative to other URLs on your site. Valid values range from 0.0 to 1.0. This value does not affect how your pages are compared to pages on other sites—it only lets the search engines know which pages you deem most important for the crawlers.

## exclusions

Type: `Array`

Default: `['404']`

Pages to omit from the sitemap.

```js
options: {
  sitemap: {
    exclusions: ["foo", "bar"],
  },
  files: {
    ...
  }
}
```

## relativedest

Type: `String` / `Boolean`

Default: `false`

Path to which the URLs in Sitemap and Robots should be relative to. `true` is equal to the destination path `dest` and `false` is equal to the root directory.

## robot

Type: `Boolean`

Default: `true`

Generate robots.txt from `exclusions` list.

## Usage Examples

## Simple

To simplify might do something like:

```js
assemble: {
  blog: {
    options: {
      plugins: ['grunt-assemble-sitemap'],
    },
    files: {
      './blog/': ['./templates/blog/*.hbs']
    }
  }
}
```

## Result

```js
./blog/sitemap.xml
./blog/robots.txt
```

## Advanced

```js
assemble: {
  blog: {
    options: {
      plugins: ['grunt-assemble-sitemap'],
      sitemap: {
        homepage: 'http://assemble.io',
            changefreq: 'daily',
            priority: '0.8',
            exclude: ['50x', 'foo'],
            robot: false
      }
    },
    files: {
      './blog/': ['./templates/blog/*.hbs']
    }
  }
}
```

## Result

```js
./blog/sitemap.xml
```

## Contributing

We welcome all kinds of contributions! The most basic way to show your support is to star the project, and if you'd like to get involved please see the [Contributing to grunt-assemble-sitemap](http://assemble.io/contributing/) guide for information on contributing to this project.

***

## Other grunt-assemble plugins

* [grunt-assemble](https://www.npmjs.com/package/grunt-assemble): Static site generator for Grunt.js, Yeoman and Node.js. Used by Zurb Foundation, Zurb Ink, H5BP/Effeckt,… [more](https://www.npmjs.com/package/grunt-assemble) | [homepage](http://assemble.io)
* [grunt-assemble-anchors](https://www.npmjs.com/package/grunt-assemble-anchors): Assemble plugin for creating anchor tags from headings in generated html using Cheerio.js. | [homepage](https://github.com/assemble/grunt-assemble-anchors)
* [grunt-assemble-contextual](https://www.npmjs.com/package/grunt-assemble-contextual): Generates a JSON file with the context of each page. Basic plugin to help see… [more](https://www.npmjs.com/package/grunt-assemble-contextual) | [homepage](https://github.com/assemble/grunt-assemble-contextual)
* [grunt-assemble-decompress](https://www.npmjs.com/package/grunt-assemble-decompress): Assemble plugin for extracting zip, tar and tar.gz archives. | [homepage](https://github.com/assemble/grunt-assemble-decompress)
* [grunt-assemble-download](https://www.npmjs.com/package/grunt-assemble-download): Assemble plugin for downloading files from GitHub. | [homepage](https://github.com/assemble/grunt-assemble-download)
* [grunt-assemble-i18n](https://www.npmjs.com/package/grunt-assemble-i18n): Plugin for adding i18n support to Assemble projects. | [homepage](https://github.com/assemble/grunt-assemble-i18n)
* [grunt-assemble-lunr](https://www.npmjs.com/package/grunt-assemble-lunr): Assemble plugin for adding search capabilities to your static site, with lunr.js. | [homepage](http://assemble.io)
* [grunt-assemble-navigation](https://www.npmjs.com/package/grunt-assemble-navigation): Assemble navigation plugin. Automatically generate Bootstrap-style, multi-level side nav. See the sidenav on assemble.io for… [more](https://www.npmjs.com/package/grunt-assemble-navigation) | [homepage](https://github.com/assemble/grunt-assemble-navigation)
* [grunt-assemble-permalinks](https://www.npmjs.com/package/grunt-assemble-permalinks): Permalinks plugin for Assemble, the static site generator for Grunt.js, Yeoman and Node.js. This plugin… [more](https://www.npmjs.com/package/grunt-assemble-permalinks) | [homepage](https://github.com/assemble/grunt-assemble-permalinks)
* [grunt-assemble-wordcount](https://www.npmjs.com/package/grunt-assemble-wordcount): Assemble plugin for displaying wordcount and average reading time to blog posts or pages. | [homepage](https://github.com/assemble/grunt-assemble-wordcount)

***

## Author

**Hariadi Hinta**

+ [github/hariadi](https://github.com/hariadi)
+ [twitter/hariadi](http://twitter.com/hariadi)

## License

Copyright © 2015 Hariadi Hinta
Released under the MIT license.

***

## Changes

**DATE**       **VERSION**   **CHANGES**

* 2015-09-25   v0.2.6        Rename to `grunt-assemble-sitemap`
* 2014-06-01   v0.2.5        fix sitemap and robots not generated,relativedest can be a path now
* 2014-06-01   v0.2.4        added sitemap URL to robots.txt,added relativedest to options
* 2014-05-03   v0.2.3        fixes toc,Change docs to use verb
* 2014-03-26   v0.2.2        Change from plugin to middleware
* 2014-02-21   v0.2.1        fix option.robot was ignored and always true 0159123,(feat) add option.dest
and use as output path,fix option.robot was ignored and always true,(feat)
add option to overwrite changefreq per file,cosmetical changes (code
formatting, naming, simplify),(wip) enable globbing patterns for
option.exclude
* 2014-02-05   v0.2.0        Generation of robots.txt will now respect the relativedest option.
* 2014-02-02   v0.1.9        Fix sitemap destination
* 2014-01-28   v0.1.8        Use external library,Get pages from assemble object
* 2014-01-03   v0.1.7        Add relativedest option
* 2013-12-12   v0.1.6        Fix plugin name in Usage Examples,Update deps
* 2013-11-28   v0.1.4        Updates dependencies to work with Grunt 0.4.2,[object Object],Add TOC to
docs
* 2013-10-20   v0.1.3        Fix sitemap and robots.txt generated on every folder,Update docs
options:exclusions
* 2013-10-18   v0.1.2        Fix homepage
* 2013-10-17   v0.1.1        Add option to generate robots.txt,Change name to
assemble-contrib.sitemap,Move to Assemble main repo
* 2013-10-01   v0.1.0        First commmit.,Add option to exclude

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on September 25, 2015._